@@ -174,4 +174,15 @@ class TakemeClient:
 
         response = self.non_auth_call(body, endpoint)
 
+        return response.get("data")
+
+    def corporate_inquiry_bank_account(self, account_number, bank_code,):
+        endpoint = "corporate/account-holdername"
+        body = {
+            "account_number": account_number,
+            "bank_code": bank_code
+        }
+
+        response = self.non_auth_call(body, endpoint)
+
         return response.get("data")
\ No newline at end of file
